<?php
/**
 * Header file for the Twenty Twenty WordPress default theme.
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package WordPress
 * @subpackage Twenty_Twenty
 * @since Twenty Twenty 1.0
 */

?><!DOCTYPE html>

<html class="no-js" <?php language_attributes(); ?>>

	<head>

		<meta charset="<?php bloginfo( 'charset' ); ?>">
		<meta name="viewport" content="width=device-width, initial-scale=1.0" >

		<link rel="profile" href="https://gmpg.org/xfn/11">

		<link rel="preconnect" href="https://fonts.googleapis.com">
		<link rel="preconnect" href="https://fonts.gstatic.com" crossorigin>
		<link href="https://fonts.googleapis.com/css2?family=Montserrat:wght@500;600;700&family=PT+Sans:wght@400;700&display=swap" rel="stylesheet">

		<?php wp_head(); ?>

	</head>

	<body <?php body_class(); ?>>
		<?php
		wp_body_open();
		// Check whether the header search is activated in the customizer.
		$enable_header_search = get_theme_mod( 'enable_header_search', true );
		?>
		<header id="site-header" class="header-footer-group bg-white font-size-sm" role="banner">
			<div id="main-head" class="main-head bg-white py-lg-2">
				<div class="header-inner section-inner position-relative justify-content-between py-4 d-flex align-items-center">
					<div class="header-titles-wrapper mr-3 mr-sm-0">
						<?php
						if ( true === $enable_header_search ) {
							?>
							<button class="toggle search-toggle mobile-search-toggle" data-toggle-target=".search-modal" data-toggle-body-class="showing-search-modal" data-set-focus=".search-modal .search-field" aria-expanded="false">
								<span class="toggle-inner">
									<span class="toggle-icon">
										<?php twentytwenty_the_theme_svg( 'search' ); ?>
									</span>
									<span class="toggle-text screen-reader-text"><?php _e( 'Search', 'twentytwenty' ); ?></span>
								</span>
							</button><!-- .search-toggle -->

						<?php } ?>
						<div class="header-titles pl-0 pr-3 pr-sm-5 px-lg-0">
							<?php
								// Site title or logo.
								twentytwenty_site_logo();
							?>
						</div><!-- .header-titles -->

						<button class="toggle nav-toggle mobile-nav-toggle" data-toggle-target=".menu-modal"  data-toggle-body-class="showing-menu-modal" aria-expanded="false" data-set-focus=".close-nav-toggle">
							<span class="toggle-inner">
								<span class="toggle-icon">
									<?php twentytwenty_the_theme_svg( 'ellipsis' ); ?>
								</span>
								<span class="toggle-text"><?php _e( 'Menu', 'twentytwenty' ); ?></span>
							</span>
						</button><!-- .nav-toggle -->
					</div><!-- .header-titles-wrapper -->

					<div class="header-navigation d-flex align-items-center">
						<?php get_template_part( 'template-parts/menu' ); ?>
					</div>
				</div>
			</div><!-- .header-inner -->

			<?php
			// Output the search modal (if it is activated in the customizer).
			if ( true === $enable_header_search ) {
				get_template_part( 'template-parts/modal-search' );
			}
			?>
		</header><!-- #site-header -->

		<?php
		// Output the menu modal.
		get_template_part( 'template-parts/modal-menu' );
