<?php
/**
 * The main template file
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package WordPress
 * @subpackage Twenty_Twenty
 * @since 1.0.0
 */

get_header();
?>

<main id="site-content" role="main">
	<?php
	if(!is_search()):
		get_template_part( 'template-parts/sec', 'banner' );
	endif; ?>
	<section class="sec-row">
		<div class="section-inner">
			<div class="row">
				<div class="page-main-content col-md-8 col-lg-9">
					<?php
					$archive_custom_title    = ' ';
					$archive_title    = '';
					$archive_subtitle = '';

					if ( is_search() ) {
						global $wp_query;

						$archive_title = sprintf(
							'%1$s %2$s',
							'<span class="color-accent">' . __( 'Search:', 'twentytwenty' ) . '</span>',
							'&ldquo;' . get_search_query() . '&rdquo;'
						);

						if ( $wp_query->found_posts ) {
							$archive_subtitle = sprintf(
								/* translators: %s: Number of search results */
								_n(
									'We found %s result for your search.',
									'We found %s results for your search.',
									$wp_query->found_posts,
									'twentytwenty'
								),
								number_format_i18n( $wp_query->found_posts )
							);
						} else {
							$archive_subtitle = __( 'We could not find any results for your search. You can give it another try through the search form below.', 'twentytwenty' );
						}
					} elseif ( ! is_home() ) {
						$archive_title    = get_the_archive_title();
						$archive_subtitle = get_the_archive_description();
					}

					if ( !is_home() || $archive_title || $archive_subtitle ) {
						?>

						<header class="archive-header header-footer-group pt-0">

							<div class="archive-header-inner pb-4">

								<?php /*
								if(!is_home() && $archive_custom_title): ?>
									<h1 class="archive-title"><?php echo $archive_custom_title; ?></h1>
								<?php
								endif;*/ ?>

								<?php if ( $archive_title ) { ?>
									<h2 class="archive-title"><?php echo wp_kses_post( $archive_title ); ?></h2>
								<?php } ?>

								<?php if ( $archive_subtitle ) { ?>
									<div class="archive-subtitle thin max-percentage intro-text"><?php echo wp_kses_post( wpautop( $archive_subtitle ) ); ?></div>
								<?php } ?>

							</div><!-- .archive-header-inner -->

						</header><!-- .archive-header -->

						<?php
					}

					if ( have_posts() ) {

						$i = 0;
						?>
						<div class="block-recent-posts">
							<div class="recent-posts-wrapper row">
					            <?php
								while ( have_posts() ) {
									$i++; the_post();?>
									<div class="post-item col-sm-6 mb-5">
										<div class="item-inner position-relative pb-4 clearfix">
											<?php
											if(has_post_thumbnail()): ?>
												<div class="item-img position-relative">
													<a href="<?php echo get_permalink(); ?>" title="<?php echo get_the_title(); ?>"><?php the_post_thumbnail( 'img-thumb3', array( 'class' => 'w-100' ) ); ?></a>
												</div>
												<?php
											endif; ?>
											<div class="item-caption border p-4 mb-sm-3">
												<div class="pt-3 px-2">
													<h3 class="mb-3 has-underline text-dark"><a href="<?php echo get_permalink(); ?>" title="<?php echo get_the_title(); ?>">
														<?php echo get_the_title(); ?>
													</a></h3>
													<span class="d-block mb-2"><?php echo get_the_date(); ?></span>
													<?php the_excerpt(); ?>
												</div>
											</div>
										</div>
									</div>
									<?php
								} ?>
							</div>
						</div><?php
					} elseif ( is_search() ) {
						?>

						<div class="no-search-results-form section-inner thin">

							<?php
							get_search_form(
								array(
									'label' => __( 'search again', 'twentytwenty' ),
								)
							);
							?>

						</div><!-- .no-search-results -->

						<?php
					}
					?>

					<?php get_template_part( 'template-parts/pagination' ); ?>
				</div>
				<div class="page-sidebar col-md-4 col-lg-3">
					<?php dynamic_sidebar( 'sidebar-1' ); ?>
				</div>
			</div>
		</div>
	</section>
</main><!-- #site-content -->

<?php get_template_part( 'template-parts/footer-menus-widgets' ); ?>

<?php
get_footer();
